@@ -8,7 +8,7 @@ use strict;
 
 package XML::Compile::Schema::NameSpaces;
 use vars '$VERSION';
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
@@ -50,7 +50,7 @@ sub add(@)
 
 
 sub use($)
-{   my ($self, $schema) = @_;
+{   my $self = shift;
     push @{$self->{use}}, @_;
     @{$self->{use}};
 }
@@ -124,7 +124,7 @@ sub printIndex(@)
 
     my $show_used = exists $opts{include_used} ? $opts{include_used} : 1;
     foreach my $use ($self->use)
-    {   $use->namespaces->printIndex(%opts, include_used => 0);
+    {   $use->printIndex(%opts, include_used => 0);
     }
 
     $self;
